from distutils.core import setup
setup(
  name = 'MinioProgress',
  packages = ['MinioProgress'],
  version = '0.1.1',
  license='MIT',
  description = 'Progress Bar for Minio',
  author = 'LimanOP',
  author_email = 'liman@realiman.lol',
  url = 'https://github.com/limangit/MinioProgress',
  download_url = 'https://github.com/LimanGit/MinioProgress/archive/refs/tags/v0.1.1.zip',
  keywords = ['Minio', 'S3', 'Python', 'Progress'],
  install_requires=[],
  classifiers=[
    'Development Status :: 3 - Alpha',
    'Intended Audience :: Developers',
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',
    'Programming Language :: Python :: 3',
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
)
